import React from 'react';
import ReactDOM from 'react-dom';
import {
  scaleLinear,
  scaleTime,
  max,
  timeFormat,
  extent,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const circleRadius = 4;
const margin = {
  top: 20,
  right: 30,
  bottom: 65,
  left: 100,
};
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 50;
const tickOffset = 7;
const App = () => {
  const data = useData();
  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;

  const xValue = (d) => d.timestamp;
  const yValue = (d) => d.temperature;

  const xAxisLabel = 'Timestamp';
  const yAxisLabel = 'Temperature';

  // const siFormat =
  const xAxisTickFormat = timeFormat('%a');

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left},${margin.top})`}
      >
        <Marks
          xScale={xScale}
          yScale={yScale}
          data={data}
          yValue={yValue}
          xValue={xValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={circleRadius}
        />
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={tickOffset}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${
            innerHeight / 2
          }) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft
          yScale={yScale}
          innerWidth={innerWidth}
          tickOffset={tickOffset}
        />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
